@@ -1,3 +1,5 @@
+use Number::Format;
+
 ################################################################################
 
 sub handler {
@@ -7,9 +9,11 @@ sub handler {
 	our $apr = Apache::Request -> new ($r);
 	my $parms = $apr -> parms;
 	
+	$number_format or our $number_format = Number::Format -> new (%{$conf -> {number_format}});
+	
 	require_fresh ($_PACKAGE . '::Config');
 
-   	our $db  = DBI -> connect ($conf -> {'db_dsn'}, $conf -> {'db_user'}, $conf -> {'db_password'}, {RaiseError => 1});
+   	($db and $db -> ping) or our $db  = DBI -> connect ($conf -> {'db_dsn'}, $conf -> {'db_user'}, $conf -> {'db_password'}, {RaiseError => 1});
 
    	$conf -> {dbf_dsn} and our $dbf = DBI -> connect ($conf -> {dbf_dsn}, {RaiseError => 1});
 
