@@ -243,12 +243,17 @@ sub draw_hr {
 
 CSS- .    C<lnk4>. 
 
+=item picture 
+
+ . 
+
 =back
 
 =head2 
 
 	draw_text_cell ({ 
-		label   => '$1 000 000',
+		label   => 1000000,
+		picture => '$ ### ### ###',
 		href    => '/?type=bank&action=pillage',
 		target  => 'invisible',
 		max_len => 255,
@@ -267,6 +272,42 @@ sub draw_text_cell {
 	drawer_call ('draw_text_cell', @_);	
 }
 
+
+################################################################################
+
+=head1 draw_text_cells
+
+=head2 
+
+	draw_text_cells ([
+	
+		{ 
+			label   => 'foo',
+		},
+		
+		{ 
+			label   => 1000000,
+			picture => '$ ### ### ###',
+			href    => '/?type=bank&action=pillage',
+			target  => 'invisible',
+			max_len => 255,
+			attributes => {
+				width => '1%',
+				align => 'right',
+			},
+			a_class => 'red_hot_link'
+		},
+
+	]);
+
+=cut
+
+################################################################################
+
+sub draw_text_cells {
+	drawer_call ('draw_text_cells', @_);	
+}
+
 ################################################################################
 
 =head1 draw_checkbox_cell
